<CFSETTING ENABLECFOUTPUTONLY="Yes">
<!------------------------------------------------------------------------
NAME:           CF_Range
FILE:           range.cfm
CREATED:        04/09/1998
LAST MODIFIED:  06/29/2000
VERSION:        1.0
AUTHOR:         Rob Brooks-Bilson (rbils@amkor.com)
DESCRIPTION:    CF_Range is a custom CFML tag that calculates the Range
                for a comma delimited list (distribution) of numeric values. 
                The Range for a given distribution is determined by calculating 
                the distance between the lowest and highest value in the list. 
                Range is used to give an idea of how spread out data in a given 
                set is.  
ATTRIBUTES:     REQUIRED
                Values = Comma delimited list of numeric values
                OutVar = name to give the structure that is returned as a caller 
                         var
RETURN VALUES:  This tag returns a structure (named by the OutVar attribute) that 
                contains three key value pairs:
                MinValue = Minimum value in the list of values
                MaxValue = Maximum value in the list of values
                Range = Range calculate by subtracting the MinValue from MaxValue 
KNOWN ISSUES:   None
------------------------------------------------------------------------->
<!--- set local variables to the passed attributes.  This isn't absolutely
      necessary, but it is a good idea as it allows you to reference the
      original values again if you ever need to. --->
<CFIF IsDefined('Attributes.Values') AND Attributes.Values NEQ "">
  <CFSET Local_Values = Attributes.Values>
<CFELSE>
  <CFOUTPUT>
  You failed to pass a required attribute: <B>Values</B>   
  </CFOUTPUT>
  <CFABORT>
</CFIF>


<CFIF IsDefined('Attributes.OutVar') AND Attributes.OutVar NEQ "">
  <CFSET Local_OutVar = Attributes.OutVar>
<CFELSE>
  <CFOUTPUT>
  You failed to pass a required attribute: <B>OutVar</B>   
  </CFOUTPUT>
  <CFABORT>
</CFIF>

<!--- Make sure numeric values were passed --->
<CFLOOP INDEX="i" FROM="1" TO="#ListLen(Local_Values)#">
  <CFIF NOT IsNumeric(ListGetAt(Local_Values, i, ","))>
    <CFOUTPUT>
    <H3>You attempted to pass a non-numeric value to this tag.  All values must 
        be numeric.</H3>
    </CFOUTPUT>
    <CFABORT>
  </CFIF>
</CFLOOP>

<!--- get the number of elements in the List --->
<CFSET NumberOfElements = ListLen(Local_Values)>

<!--- Build an array from the list --->
<CFSET MyArray = ArrayNew(1)>

<CFLOOP INDEX="n" FROM="1" TO="#NumberOfElements#">
    <CFSET MyArray[n] = ListGetAt(Local_Values, n, ",")>
</CFLOOP>

<!--- Create a structure called MyStruct and populate it with the minimum
      and maximum values from MyArray.  This is a temporary structure that
      will be renamed before it is sent back to the calling template.  
      Also calculate the range and assign it to a third structure key. --->
<CFSET MyStruct = StructNew()>
<CFSET MyStruct.MinValue = ArrayMin(MyArray)>
<CFSET MyStruct.MaxValue = ArrayMax(MyArray)>
<CFSET MyStruct.Range = MyStruct.MaxValue - MyStruct.MinValue>


<!--- Copy MyStruct to the caller variable name passed into the tag by the 
      OutVar attribute. --->
<CFSET "Caller.#Local_OutVar#" = MyStruct>
<CFSETTING ENABLECFOUTPUTONLY="No">
